Data type routines¶
Returns |
|
Returns the type that results from applying the NumPy type promotion rules to the arguments. |
|
Return a scalar type which is common to the input arrays. |
Creating data types¶
Data type information¶
Data type testing¶
Returns a boolean indicating whether a provided dtype is of a specified data type kind. |
|
Returns |